import { get,post } from "./index";

/**
 * 获取我的图库分类
 */
export function apiMyClassifyList(){
    return get('/my_chart/classify/list',{})
}

/**
 * 获取公共图库分类
 */
export function apiPublicClassifyList(){
    return get('/my_chart/classify/public_list',{})
}

/**
 * 新增我的分类
 * @param MyChartClassifyName
 */
export function apiAddClassify(params){
    return post('/my_chart/classify/add',params)
}

/**
 * 编辑我的分类
 * @param MyChartClassifyName
 * @param MyChartClassifyId
 */
export function apiEidtClassify(params){
    return post('/my_chart/classify/edit',params)
}

/**
 * 删除我的分类
 * @param MyChartClassifyId
 */
export function apiDeleteClassify(params){
    return post('/my_chart/classify/delete',params)
}

/**
 * 将分类设置共享
 * @param IsPublic 1共享 0不共享
 * @param MyChartClassifyId
 */
export function apiShareClassify(params){
    return post('/my_chart/classify/modify_public',params)
}

/**
 * 复制公共图库分类
 * @param MyChartClassifyId 
 */
export function apiClassifyCopy(params){
    return post('/my_chart/classify/copy',params)
}

/**
 * 获取图库分类下的图列表
 * @param PageSize
 * @param CurrentIndex
 * @param MyChartClassifyId
 */
export function apiMyChartList(params){
    return get('/my_chart/list',params)
}

/**
 * 将图表从我的图库中移除
 * @param MyChartClassifyId
 * @param MyChartId
 */
export function apiMyChartRemove(params){
    return post('/my_chart/delete',params)
}

/**
 * 将图表加入我的图库分类中
 * @param ChartInfoId
 * @param {Array} MyChartClassifyId eg:[462,456]
 */
export function apiMyChartAdd(params){
    return post('/my_chart/add',params)
}

/**
 * 获取当前的图在我的图库中哪些分类存在
 * @param ChartInfoId
 */
export function apiChartInMyClassifyList(params){
    return get('/my_chart/get_mychart_classify_id_list',params)
}

/**
 * 将图表加入图库分类中
 * @param ChartInfoId
 * @param {arr} MyChartClassifyId
 */
export function apiChartAddToClassify(params){
    return post('/my_chart/add_to_classify',params)
}

/**
 * 删除图表分类/图表
 * @param ChartClassifyId
 * @param ChartInfoId
 */
export function apiChartDel(params){
    return post('/datamanage/chart_classify/delete',params)
}

/**
 * myETA搜索我的图库数据
 * @param Keyword
 * @param CurrentIndex
 * @param PageSize
 */
export function apiMyETAChartSearch(params){
    return get('/my_chart/search_by_es',params)
}

export default{
    /**
     * 获取我的图库分类
     */
    myClassifyList(){
        return get('/my_chart/classify/list',{})
    },
    /**
     * 获取公共图库分类
     */
    publicClassifyList(){
        return get('/my_chart/classify/public_list',{})
    },
    /**
     * 新增我的分类
     * @param MyChartClassifyName
     */
    addClassify(params){
        return post('/my_chart/classify/add',params)
    },
    /**
     * 编辑我的分类
     * @param MyChartClassifyName
     * @param MyChartClassifyId
     */
    eidtClassify(params){
        return post('/my_chart/classify/edit',params)
    },
    /**
     * 删除我的分类
     * @param MyChartClassifyId
     */
    deleteClassify(params){
        return post('/my_chart/classify/delete',params)
    },
    /**
     * 将分类设置共享
     * @param IsPublic 1共享 0不共享
     * @param MyChartClassifyId
     */
    shareClassify(params){
        return post('/my_chart/classify/modify_public',params)
    },
    /**
     * 复制公共图库分类
     * @param MyChartClassifyId 
    */
    classifyCopy(params){
        return post('/my_chart/classify/copy',params)
    },
    /**
     * 获取图库分类下的图列表
     * @param PageSize
     * @param CurrentIndex
     * @param MyChartClassifyId
     */
    myChartList(params){
        return get('/my_chart/list',params)
    },
    /**
     * 将图表从我的图库中移除
     * @param MyChartClassifyId
     * @param MyChartId
     */
    myChartRemove(params){
        return post('/my_chart/delete',params)
    },
    /**
     * 将图表加入我的图库分类中
     * @param ChartInfoId
     * @param {Array} MyChartClassifyId eg:[462,456]
     */
    myChartAdd(params){
        return post('/my_chart/add',params)
    },
    /**
     * 获取当前的图在我的图库中哪些分类存在
     * @param ChartInfoId
     */
    chartInMyClassifyList(params){
        return get('/my_chart/get_mychart_classify_id_list',params)
    },
    /**
     * 将图表加入图库分类中
     * @param ChartInfoId
     * @param {arr} MyChartClassifyId
     */
    chartAddToClassify(params){
        return post('/my_chart/add_to_classify',params)
    },
    /**
     * 删除图表分类/图表
     * @param ChartClassifyId
     * @param ChartInfoId
     */
    chartDel(params){
        return post('/datamanage/chart_classify/delete',params)
    },
    /**
     * myETA搜索我的图库数据
     * @param Keyword
     * @param CurrentIndex
     * @param PageSize
     */
    myETAChartSearch(params){
        return get('/my_chart/search_by_es',params)
    },
    /**
     * 我的图库分类排序
     * @param MyChartClassifyId
     * @param NextClassifyId
     * @param PrevClassifyId
     */
    myETAClassifySort(params){
        return post('/my_chart/classify/move',params)
    },
    /**
     * myETA中保存商品价格曲线图
     * @param {*} params ChartInfoId LeftMin LeftMax
     */
    myETASaveChart(params){
        return post('/future_good/chart_info/save',params)
    },
    /**
     * 获取myETA图库关联的节点列表
     * @param {*} params 
     * @returns 
     */
    getFrameNode(params){
        return get('/my_chart/classify/framework_node_list',params)
    }
}